@@ -55,7 +55,9 @@ Date::Manip - powerful date manipulation routines
 
  The following routines are used by the above routines (though they can
  also be called directly).  Make sure that $y is entered as the full 4
- digit year... 2 digit years may give wrong results.
+ digit year... 2 digit years may give wrong results.  Most (if not all)
+ of the information below can be gotten from UnixDate which is really
+ the way I intended it to be gotten.
 
  $day=&Date_DayOfWeek($m,$d,$y)
  $secs=&Date_SecsSince1970($m,$d,$y,$h,$mn,$s)
@@ -190,6 +192,11 @@ Times may be written as:
      hh:MN am
      hh:MN:SS am
 
+Fractional seconds are also supported in parsing both as:
+  HH:MN:SS:SSSS
+  HH:MN:SS.SSSS
+but the fractional part is discarded.
+
 Valid formats for a full date and time (and examples of how Dec 10, 1965 at
 9:00 pm might appear) are:
   DateTime
@@ -640,7 +647,7 @@ use strict;
 #    UnixDate will now return a scalar or list depending on context
 #    ParseDate/ParseDateDelta will now take a scalar, a reference to a
 #       scalar, or a eference to an array
-#    Added copyright notice (requested by Tim Bunce)
+#    Added copyright notice (requested by Tim Bunce <Tim.Bunce@ig.co.uk>)
 #    Simple timezone handling
 #    Added Date_SetTime, Date_GetPrev, Date_GetNext
 #
@@ -650,7 +657,8 @@ use strict;
 #        "24:xx:00".
 #
 # Version 5.00  06/21/96
-#    Switched to a package (patch supplied by Peter Bray)
+#    Switched to a package (patch supplied by Peter Bray
+#       <pbray@ind.tansu.com.au>)
 #      o  renamed to Date::Manip
 #      o  changed version number to 2 decimal places
 #      o  added POD documentation
@@ -659,7 +667,7 @@ use strict;
 #       an uninitialized variable.
 #
 # Version 5.01  06/24/96
-#    Fixes suggested by Rob Perelman
+#    Fixes suggested by Rob Perelman <robp@electriciti.com>
 #      o  Fixed a typo (Friday misspelled Fridat)
 #      o  Documentation problem for \$err in DateCalc
 #    Reworked a number of the ParseDate regular expressions to make
@@ -682,6 +690,17 @@ use strict;
 #       in the future, uncomment them.  They are marked with "***FUTURE"
 #    Declared package variables to avoid warning "Identifier XXX used
 #       only once".  Thanks to Peter Bray for the suggestion.
+#
+# Version 5.04  08/01/96
+#    Added support for fractional seconds (as generated by Sybase).  They
+#       are parsed and ignored.  Added by Kurt Stephens
+#       <stephens@il.us.swissbank.com>.
+#    Fixed bugs reported by J.B. Nicholson-Owens
+#       <jbn@mystery-train.cu-online.com>
+#      o  "Tue Jun 25 1996" wasn't parsed correctly (regexp was case sensitive)
+#      o  full day names not parsed correctly
+#      o  the default day in ErrorCheck should be 1, NOT currd since when
+#         currd>28, it may not be a valid date for the month
 
 ########################################################################
 # TODO
@@ -689,9 +708,32 @@ use strict;
 
 # ### SHORT TERM ###
 
+# Suggested by: Matthew R. Sheahan <chaos@crystal.palace.net>
+# It would be really pleasant if &ParseDate in this module could understand
+# ctime() format dates, i.e. "Tue Jul 30 20:13:05 EDT 1996" from /bin/date
+# or "Tue Jul 30 20:13:17 1996" from ctime.pl.
+
+# Meet RFC 822 (will work as soon as comma support and timezone support added)
+#   day "," date time zone
+#      zone        =  "UT"  / "GMT"                ; Universal Time
+#                                                  ; North American : UT
+#                  /  "EST" / "EDT"                ;  Eastern:  - 5/ - 4
+#                  /  "CST" / "CDT"                ;  Central:  - 6/ - 5
+#                  /  "MST" / "MDT"                ;  Mountain: - 7/ - 6
+#                  /  "PST" / "PDT"                ;  Pacific:  - 8/ - 7
+#                  /  1ALPHA                       ; Military: Z = UT;
+#                                                  ;  A:-1; (J not used)
+#                                                  ;  M:-12; N:+1; Y:+12
+#                  / ( ("+" / "-") 4DIGIT )        ; Local differential
+#                                                  ;  hours+min. (HHMM)
+#     UT, GMT, EST, EDT, ... , PST, PDT, A .. Z, +DDDD, -DDDD,
+
+# Fix Makefile so manpage is installed
+
 # Add a variable to NOT run Init each time.
+
 # Add better support for the syntax of international dates.
-#
+
 # Use Graham Barr's Time::Zone stuff
 # ParseDate:
 #     ignore commas when they would be appropriate
@@ -1332,8 +1374,11 @@ sub ParseDate {
   my($Yexp) ='(\d{2}|\d{4})'; # 2 or 4 digits (year)
   my($DDexp)='(\d{2})';       # 2 digits      (month/day/hour/minute/second)
   my($Dexp) ='(\d{1,2})';     # 1 or 2 digit  (month/day/hour)
-  my($Time)="(?:$DDexp:$DDexp(?::$DDexp)?(?:\\s*$ampm)?)"; # time in HH:MM:SS
-  my($time)="(?:$Dexp:$DDexp(?::$DDexp)?(?:\\s*$ampm)?)";  # time in hh:MM:SS
+  my($FDexp)='(?:[.:]\d+)?';  # fractional secs
+  # time in HH:MM:SS
+  my($Time)="(?:$DDexp:$DDexp(?::$DDexp$FDexp)?(?:\\s*$ampm)?)";
+  # time in hh:MM:SS
+  my($time)="(?:$Dexp:$DDexp(?::$DDexp$FDexp)?(?:\\s*$ampm)?)";
   my($sep)='([\/ .-])';
   my($at)='(?:\s*'.$Date::Manip::At.'\s*)';
   my($in)='(?:\s*'.$Date::Manip::In.'\s*)';
@@ -1373,7 +1418,7 @@ sub ParseDate {
 
     if (/$wkexp/i) {
       $wk=$1;
-      s/$wkexp/ /;
+      s/$wkexp/ /i;
     }
     s/\s+/ /g;                  # all whitespace are now a single space
     s/^\s+//;
@@ -1824,7 +1869,7 @@ sub Date_Init {
     @month=split(/\s+/,$month);
     $mon=join "|",@mon;
     $month=join "|",@month;
-    $Date::Manip::MonExp = "(".lc($mon)."|".lc($month).")";
+    $Date::Manip::MonExp = "(".lc($month)."|".lc($mon).")";
     for ($i=0; $i<12; $i++) {
       $mon=$mon[$i];
       $month=$month[$i];
@@ -1854,7 +1899,7 @@ sub Date_Init {
     @week=split(/\s+/,$week);
     $wk=join "|",@wk;
     $week=join "|",@week;
-    $Date::Manip::WkExp = "(".lc($wk)."|".lc($week).")";
+    $Date::Manip::WkExp = "(".lc($week)."|".lc($wk).")";
     for ($i=0; $i<7; $i++) {
       $w=$w[$i];
       $wk=$wk[$i];
@@ -2025,7 +2070,7 @@ sub Date_ErrorCheck {
   return 1        if (! &IsInt($$m,1,12));
 
   # Check day
-  $$d=$curr_d     if ($$d eq "");
+  $$d="01"        if ($$d eq "");
   $$d="0$$d"      if (length($$d)==1);
   return 1        if (! &IsInt($$d,1,$d_in_m[$$m]));
   if ($$wk) {
